@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -29,7 +29,7 @@ std::string ModuleVersion::toString() const {
   }
   if (release != 0) {
     stream << separator << 'R' << release << separator
-      << (char)('A' + patch);
+      << static_cast<char>('A' + patch);
   }
   if (build != 0) {
     stream << separator << build;
