@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -66,10 +66,10 @@ void Quad::set(unsigned char group, unsigned char plane, unsigned char row,
 }
 
 void Quad::set_hexrepr(const char* hex_repr) {
-  u.comp.group = ((hex_repr[0] - 'A') << 4) + (hex_repr[1] - 'A');
-  u.comp.plane = ((hex_repr[2] - 'A') << 4) + (hex_repr[3] - 'A');
-  u.comp.row =   ((hex_repr[4] - 'A') << 4) + (hex_repr[5] - 'A');
-  u.comp.cell =  ((hex_repr[6] - 'A') << 4) + (hex_repr[7] - 'A');
+  u.comp.group = static_cast<unsigned char>(((hex_repr[0] - 'A') << 4) + (hex_repr[1] - 'A'));
+  u.comp.plane = static_cast<unsigned char>(((hex_repr[2] - 'A') << 4) + (hex_repr[3] - 'A'));
+  u.comp.row =   static_cast<unsigned char>(((hex_repr[4] - 'A') << 4) + (hex_repr[5] - 'A'));
+  u.comp.cell =  static_cast<unsigned char>(((hex_repr[6] - 'A') << 4) + (hex_repr[7] - 'A'));
 }
 
 const Quad Quad::operator-(const Quad& rhs) const {
@@ -133,21 +133,21 @@ char* Quad::get_hexrepr(unsigned int value) {
 }
 
 void Quad::get_hexrepr(const Quad& q, char* const str) {
-  str[0] = 'A' + (q.u.comp.group >> 4); // high end
-  str[1] = 'A' + (q.u.comp.group & 15);
-  str[2] = 'A' + (q.u.comp.plane >> 4);
-  str[3] = 'A' + (q.u.comp.plane & 15);
-  str[4] = 'A' + (q.u.comp.row   >> 4);
-  str[5] = 'A' + (q.u.comp.row   & 15);
-  str[6] = 'A' + (q.u.comp.cell  >> 4);
-  str[7] = 'A' + (q.u.comp.cell  & 15); // low end
+  str[0] = static_cast<char>('A' + (q.u.comp.group >> 4)); // high end
+  str[1] = static_cast<char>('A' + (q.u.comp.group & 15));
+  str[2] = static_cast<char>('A' + (q.u.comp.plane >> 4));
+  str[3] = static_cast<char>('A' + (q.u.comp.plane & 15));
+  str[4] = static_cast<char>('A' + (q.u.comp.row   >> 4));
+  str[5] = static_cast<char>('A' + (q.u.comp.row   & 15));
+  str[6] = static_cast<char>('A' + (q.u.comp.cell  >> 4));
+  str[7] = static_cast<char>('A' + (q.u.comp.cell  & 15)); // low end
 }
 
 char* Quad::char_hexrepr(unsigned char c) {
   char hex[3];
   hex[2] = '\0';
-  hex[1] = (c & 15) + 'A';
-  hex[0] = (c >> 4) + 'A';
+  hex[1] = static_cast<char>((c & 15) + 'A');
+  hex[0] = static_cast<char>((c >> 4) + 'A');
   return mcopystr(hex);
 }
 
@@ -235,7 +235,7 @@ char* QuadInterval::generate_posix() {
                 Free(str);
                 q1.set(j, 0);
                 if (j > 0 && q1[j-1] < 255)
-                  q1.set(j - 1, q1[j-1] + 1);
+                  q1.set(j - 1, static_cast<unsigned char>(q1[j-1] + 1));
                 for (k = j + 1; k < 4; k++) {
                   res = mputprintf(res, "%s",
                     str = generate_hex_interval(0, 255));
@@ -251,8 +251,8 @@ char* QuadInterval::generate_posix() {
               res = mputstr(res, str = Quad::char_hexrepr(lower[j]));
               Free(str);
             }
-            str = generate_hex_interval(lower[c] + 1,
-              (unsigned char)(lower[c] + diff[c] - 1));
+            str = generate_hex_interval(static_cast<unsigned char>(lower[c] + 1),
+              static_cast<unsigned char>(lower[c] + diff[c] - 1));
             res = mputprintf(res, "%s", str);
             Free(str);
             k = (3 - c) * 2;
@@ -274,7 +274,7 @@ char* QuadInterval::generate_posix() {
               }
               c++;
               if (c < 3)
-                q2.set(c, upper[c] - 1);
+                q2.set(c, static_cast<unsigned char>(upper[c] - 1));
               res = mputstr(res, str = generate_hex_interval(q1[c], q2[c]));
               Free(str);
               for (j = c + 1; j < 4; j++) {
@@ -328,20 +328,20 @@ char* QuadInterval::generate_hex_interval(unsigned char source,
     if (lo < 0) { // This is possibly reported during parsing.
       TTCN_pattern_error("Illegal interval in set: start > end.");
     } else if (lo > 0) {
-      res = mputc(res, (char)s_hi);
+      res = mputc(res, static_cast<char>(s_hi));
       if (s_lo == 'A' && d_lo == 'P')
         res = mputc(res, '.');
       else
         res = mputprintf(res, "[%c-%c]", s_lo, d_lo);
     } else {
-      res = mputc(res, (char)s_hi);
-      res = mputc(res, (char)s_lo);
+      res = mputc(res, static_cast<char>(s_hi));
+      res = mputc(res, static_cast<char>(s_lo));
     }
     return res;
   }
 
-  bool alt = false;
   if (hi > 0) {
+    bool alt = false;
     if (s_lo != 'A') {
       res = mputprintf(res, "%c[%c-P]", s_hi, s_lo);
       s_hi++;
@@ -593,9 +593,8 @@ void QuadSet::do_negate() {
 }
 
 void QuadSet::add_negate_interval(const Quad& q1, const Quad& q2) {
-  unsigned int w;
   if (q2 >= q1) {
-    w = q2.get_value() - q1.get_value();
+    unsigned int w = q2.get_value() - q1.get_value();
     if (w > 0)
       add(new QuadInterval(q1, q2));
     else {
