@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -936,8 +936,8 @@ size_t mstrlen(const expstring_t str)
   } else return 0;
 }
 
-char * buildstr(int b) {
-  if (b < 0 || b > 99) return NULL; /* invalid */
+char * buildstr(unsigned int b) {
+  if (b > 99) return NULL; /* invalid */
   if (b == 99) return memptystr(); /* empty string for full version */
   return mprintf("%02d", b);
 }
