@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -36,7 +36,7 @@ void operator delete(void *ptr) throw()
 
 void operator delete[](void *ptr) throw()
 {
-    if (ptr != (void*)&dummy) Free(ptr);
+    if (ptr != static_cast<void*>(&dummy)) Free(ptr);
 }
 
 /**************************************************************************/
