@@ -1,5 +1,5 @@
 ///////////////////////////////////////////////////////////////////////////////
-// Copyright (c) 2000-2016 Ericsson Telecom AB
+// Copyright (c) 2000-2017 Ericsson Telecom AB
 // All rights reserved. This program and the accompanying materials
 // are made available under the terms of the Eclipse Public License v1.0
 // which accompanies this distribution, and is available at
@@ -244,14 +244,14 @@ std::string ProjectDescriptor::setRelativePathTo(const std::string& absPathTo)
   }
 
   size_t slashCount = 0;
-  for (size_t i = lastSlash; i < projectAbsWorkingDir.size(); ++i) {
+  for (i = lastSlash; i < projectAbsWorkingDir.size(); ++i) {
     if (projectAbsWorkingDir.at(i) == SEPARATOR)
       ++slashCount;
   }
 
   std::string relPath;
   const std::string upDir("../");
-  for (size_t i = 0; i < slashCount; ++i)
+  for (i = 0; i < slashCount; ++i)
     relPath.append(upDir);
 
   std::string pathTo = absPathTo.substr(lastSlash+1); // we left the heading slash
@@ -315,7 +315,8 @@ ProjectGenHelper::ProjectGenHelper() :
   Wflag(false),
   Hflag(false),
   projs(),
-  checkedProjs()
+  checkedProjs(),
+  projsNameWithAbsPath()
 {}
 
 void ProjectGenHelper::addTarget(const char* projName)
@@ -699,7 +700,9 @@ bool ProjectGenHelper::sanityCheck()
     for (std::map<std::string, ProjectDescriptor>::reverse_iterator rit = projs.rbegin(); rit != projs.rend(); ++rit) {
       if ((rit->second).isLibrary() && (rit->second).getLinkingStrategy()) { //dynamic library 
         ProjectDescriptor& proj = rit->second;
-        found = DynamicLibraryChecker(&proj, found, &execName);
+        std::vector<std::string> history;
+        history.push_back(proj.getProjectName());
+        found = DynamicLibraryChecker(&proj, found, &execName, history);
         if (found) {
            ERROR("Project \"%s\" is dynamic linked library. Sub project \"%s\" is executable.\n"
                  "in TPD file, %s's all sub-level defaultTarget shall be set library too.",
@@ -748,7 +751,8 @@ void ProjectGenHelper::cleanUp()
 
 bool ProjectGenHelper::DynamicLibraryChecker(const ProjectDescriptor* desc,
                                        bool& found,
-                                       char** executableName)
+                                       char** executableName,
+                                       std::vector<std::string>& history)
 {
   if (found || !desc) return true;
   for (size_t i = 0; i < desc->numOfReferencedProjects(); ++i) {
@@ -756,7 +760,19 @@ bool ProjectGenHelper::DynamicLibraryChecker(const ProjectDescriptor* desc,
     const ProjectDescriptor* subProj = getTargetOfProject(refProjName);
     if (0 == checkedProjs.count(subProj->getProjectName())) {
       if (subProj->isLibrary()) {
-        found = DynamicLibraryChecker(subProj, found, executableName);
+        // Check if we already checked this subproject.
+        bool inHistory = false;
+        for (size_t j = 0; j < history.size(); j++) {
+          if (history[j] == subProj->getProjectName()) {
+            inHistory = true;
+            ERROR("Project hierarchy has circular references which is not supported when the improved linking method is used.\n"
+                  "For further information see the TITAN referenceguide.");
+          }
+        }
+        if (!inHistory) {
+          found = DynamicLibraryChecker(subProj, found, executableName, history);
+          history.push_back(subProj->getProjectName());
+        }
       }
       else { // search for executable under dynamic linked library
         found = true;
@@ -772,3 +788,17 @@ bool ProjectGenHelper::DynamicLibraryChecker(const ProjectDescriptor* desc,
   return found;
 }
 
+bool ProjectGenHelper::insertAndCheckProjectName(const char *absPath, const char *projName) {
+  if (projName == NULL) return true;
+  std::string absPathStr = std::string(absPath);
+  std::map<const std::string, const std::string>::iterator it = projsNameWithAbsPath.find(absPathStr);
+   if (it == projsNameWithAbsPath.end()) {
+    projsNameWithAbsPath.insert(std::pair<const std::string, const std::string>(absPathStr, std::string(projName)));
+    return true;
+  } else {
+    if (it->second != projName) {
+      return false;
+    }
+  }
+  return true;
+}
