@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -41,6 +41,8 @@ XerAttributes::XerAttributes()
 , block_(false)
 , decimal_(false)
 , defaultForEmpty_(0)
+, defaultForEmptyIsRef_(false)
+, defaultForEmptyRef_(0)
 , defaultValue_(0)
 , element_(false)
 , embedValues_(false)
@@ -62,6 +64,7 @@ XerAttributes::XerAttributes()
 , useType_(false)
 , useUnion_(false)
 , whitespace_(PRESERVE)
+, xsd_type(XSD_NONE)
 {
   //__asm("int3");
   //fprintf(stderr, "XER attributes(%p) new\n", (void*)this);
@@ -82,6 +85,7 @@ XerAttributes::~XerAttributes()
 
   Free(defaultForEmpty_);
   delete defaultValue_;
+  delete defaultForEmptyRef_;
 
   FreeNameChange(name_);
   FreeNamespace(namespace_);
@@ -169,7 +173,10 @@ void XerAttributes::print(const char *type_name) const {
     fputs(block_ ? "BLOCK\n" : "", stderr);
     fputs(decimal_ ? "DECIMAL\n" : "", stderr);
 
-    if (defaultForEmpty_)  fprintf(stderr, "DEFAULT-FOR-EMPTY '%s'\n", defaultForEmpty_);
+    if (defaultForEmpty_)
+      fprintf(stderr, "DEFAULT-FOR-EMPTY '%s' %s\n",
+        defaultForEmptyIsRef_ ? defaultForEmptyRef_->get_dispname().c_str() : defaultForEmpty_,
+        defaultForEmptyIsRef_ ? "(reference) " : "");
 
     if (element_) fputs("ELEMENT\n", stderr);
     fputs(embedValues_ ? "EMBED-VALUES\n" : "", stderr);
@@ -282,6 +289,13 @@ other.print("other");
   if (other.defaultForEmpty_ != 0) {
     Free(defaultForEmpty_);
     defaultForEmpty_ = mcopystr(other.defaultForEmpty_);
+    defaultForEmptyIsRef_ = other.defaultForEmptyIsRef_;
+  }
+  
+  defaultForEmptyIsRef_ |= other.defaultForEmptyIsRef_;
+  if (other.defaultForEmptyRef_ != 0) {
+    Free(defaultForEmptyRef_);
+    defaultForEmptyRef_ = other.defaultForEmptyRef_->clone();
   }
 
   element_ |= other.element_;
@@ -378,6 +392,10 @@ other.print("other");
   useType_ |= other.useType_;
   useUnion_ |= other.useUnion_;
   whitespace_ = other.whitespace_;
+
+  if (other.xsd_type != XSD_NONE) {
+    xsd_type = other.xsd_type;
+  }
   return *this;
 }
 
@@ -391,6 +409,8 @@ bool XerAttributes::empty() const
   && !block_
   && !decimal_
   && defaultForEmpty_ == 0
+  && !defaultForEmptyIsRef_
+  && !defaultForEmptyRef_
   && !element_
   && !embedValues_
   && !(form_ & LOCALLY_SET)
@@ -407,6 +427,7 @@ bool XerAttributes::empty() const
   && !useQName_
   && !useType_
   && !useUnion_
-  && whitespace_ == PRESERVE;
+  && whitespace_ == PRESERVE
+  && xsd_type == XSD_NONE;
 }
 
