@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -529,7 +529,7 @@ namespace Asn {
           pos2++;
         pos2+=is_constraint(pos2);
         if(tb->get_at(pos2)->get_token()==KW_OF) {
-          pos2+=tb->get_at(pos2+1)->get_token()==TOK_LowerIdentifier?2:1;
+          pos2+=tb->get_at(pos2+1)->get_token()==TOK_LowerIdentifier?static_cast<size_t>(2):static_cast<size_t>(1);
           pos2+=is_type(pos2);
         }
       }
