@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -646,7 +646,7 @@ namespace Asn {
 
   void TokenBuf::dump(unsigned level) const
   {
-    DEBUG(level, "Tokens: (%lu pcs.)", (unsigned long) tokens->size());
+    DEBUG(level, "Tokens: (%lu pcs.)", static_cast<unsigned long>( tokens->size() ));
     level++;
     for(size_t i=0; i<tokens->size(); i++)
       (*tokens)[i]->dump(level);
