@@ -43,6 +43,7 @@ void defEnumClass(const enum_def *edef, output_struct *output)
   boolean text_needed= edef->hasText && enable_text();
   boolean xer_needed = edef->hasXer && enable_xer();
   boolean json_needed = edef->hasJson && enable_json();
+  boolean oer_needed = edef->hasOer && enable_oer();
 
   char *enum_type, *qualified_enum_type, *unknown_value, *unbound_value;
   enum_type = mcopystr("enum_type");
@@ -268,8 +269,8 @@ void defEnumClass(const enum_def *edef, output_struct *output)
     "{\n", qualified_enum_type, name);
   for (i = 0; i < edef->nElements; i++) {
     if (edef->elements[i].text) {
-      src = mputprintf(src, "if (!strcmp(str_par, \"%s\") || !strcmp(str_par, \"%s\")) return %s;\n"
-        "else ", edef->elements[i].text, edef->elements[i].dispname, edef->elements[i].name);
+      src = mputprintf(src, "if (!strcmp(str_par, \"%s\") || !strcmp(str_par, \"%s\") || !strcmp(str_par, \"%s\")) return %s;\n"
+        "else ", edef->elements[i].text, edef->elements[i].descaped_text, edef->elements[i].dispname, edef->elements[i].name);
     }
     else {
       src = mputprintf(src, "if (!strcmp(str_par, \"%s\")) return %s;\n"
@@ -442,9 +443,11 @@ void defEnumClass(const enum_def *edef, output_struct *output)
     "}\n\n", name, enum_type, dispname);
 
   /* BER functions */
-  if(ber_needed || raw_needed || text_needed || xer_needed || json_needed)
+  if(ber_needed || raw_needed || text_needed || xer_needed || json_needed
+    || oer_needed) {
     def_encdec(name, &def, &src, ber_needed,
-               raw_needed,text_needed, xer_needed, json_needed, TRUE);
+               raw_needed,text_needed, xer_needed, json_needed, oer_needed, TRUE);
+  }
   if(ber_needed) {
     src=mputprintf(src,
        "ASN_BER_TLV_t* %s::BER_encode_TLV(const TTCN_Typedescriptor_t&"
@@ -788,15 +791,17 @@ void defEnumClass(const enum_def *edef, output_struct *output)
   if (json_needed) {
     // JSON encode
     src = mputprintf(src,
-      "int %s::JSON_encode(const TTCN_Typedescriptor_t&, JSON_Tokenizer& p_tok) const\n"
+      "int %s::JSON_encode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok) const\n"
       "{\n"
       "  if (enum_value == %s) {\n"
       "    TTCN_EncDec_ErrorContext::error(TTCN_EncDec::ET_UNBOUND,\n"
       "      \"Encoding an unbound value of enumerated type %s.\");\n"
       "    return -1;\n"
       "  }\n\n"
-      "  char* tmp_str = mprintf(\"\\\"%%s\\\"\", enum_to_str(enum_value));\n"
-      "  int enc_len = p_tok.put_next_token(JSON_TOKEN_STRING, tmp_str);\n"
+      "  char* tmp_str = p_td.json->as_number ? mprintf(\"%%d\", enum_value) : "
+      "mprintf(\"\\\"%%s\\\"\", enum_to_str(enum_value));\n"
+      "  int enc_len = p_tok.put_next_token(p_td.json->as_number ? "
+      "JSON_TOKEN_NUMBER : JSON_TOKEN_STRING, tmp_str);\n"
       "  Free(tmp_str);\n"
       "  return enc_len;\n"
       "}\n\n"
@@ -823,7 +828,7 @@ void defEnumClass(const enum_def *edef, output_struct *output)
       "    JSON_ERROR(TTCN_EncDec::ET_INVAL_MSG, JSON_DEC_BAD_TOKEN_ERROR, \"\");\n"
       "    return JSON_ERROR_FATAL;\n"
       "  }\n"
-      "  else if (JSON_TOKEN_STRING == token || use_default) {\n"
+      "  else if ((JSON_TOKEN_STRING == token && !p_td.json->as_number) || use_default) {\n"
       "    if (use_default || (value_len > 2 && value[0] == '\\\"' && value[value_len - 1] == '\\\"')) {\n"
       "      if (!use_default) value[value_len - 1] = 0;\n"
       "      enum_value = str_to_enum(value + (use_default ? 0 : 1));\n"
@@ -834,18 +839,92 @@ void defEnumClass(const enum_def *edef, output_struct *output)
       "    } else {\n"
       "      error = TRUE;\n"
       "    }\n"
-      "  } else {\n"
+      "  }\n"
+      "  else if (JSON_TOKEN_NUMBER == token && p_td.json->as_number) {\n"
+      "    char* value_str = mcopystrn(value, value_len);\n"
+      "    int number = atoi(value_str);\n"
+      "    if (strchr(value_str, '.') != NULL || strchr(value_str, 'e') != NULL "
+      "|| strchr(value_str, 'E') != NULL) {\n"
+      "      error = TRUE;\n"
+      "    }\n"
+      "    else if (is_valid_enum(number)) {\n"
+      "      enum_value = static_cast<%s>(number);\n"
+      "    }\n"
+      "    else {\n"
+      "      error = TRUE;\n"
+      "    }\n"
+      "    Free(value_str);\n"
+      "  }\n"
+      "  else {\n"
       "    enum_value = %s;\n"
       "    return JSON_ERROR_INVALID_TOKEN;\n"
       "  }\n\n"
       "  if (error) {\n"
-      "    JSON_ERROR(TTCN_EncDec::ET_INVAL_MSG, JSON_DEC_FORMAT_ERROR, \"string\", \"enumerated\");\n"
+      "    JSON_ERROR(TTCN_EncDec::ET_INVAL_MSG, JSON_DEC_FORMAT_ERROR, "
+      "p_td.json->as_number ? \"number\" : \"string\", \"enumerated\");\n"
       "    enum_value = %s;\n"
       "    return JSON_ERROR_FATAL;\n"
       "  }\n"
       "  return (int)dec_len;\n"
       "}\n\n"
-      , name, unknown_value, unbound_value, unbound_value);
+      , name, unknown_value, enum_type, unbound_value, unbound_value);
+  }
+  
+  if (oer_needed) {
+    // OER encode
+    src = mputprintf(src,
+      "int %s::OER_encode(const TTCN_Typedescriptor_t&, TTCN_Buffer& p_buf) const\n"
+      "{\n"
+      "  if (enum_value == %s) {\n"
+      "    TTCN_EncDec_ErrorContext::error(TTCN_EncDec::ET_UNBOUND,\n"
+      "      \"Encoding an unbound value of enumerated type %s.\");\n"
+      "    return -1;\n"
+      "  }\n\n"
+      "  if (enum_value >= 0 && enum_value < 128) {\n"
+      "    char c = enum_value;\n"
+      "    p_buf.put_c(c);\n"
+      "    p_buf.increase_pos(1);\n"
+      "  } else {\n"
+      // This case is the same as encoding a not restricted integer except
+      // the first bit is set to 1 before decoding
+      "    INTEGER intval(enum_value);\n"
+      "    TTCN_Buffer buf;\n"
+      "    intval.OER_encode(INTEGER_descr_, buf);\n"
+      "    unsigned char* uc = const_cast<unsigned char*>(buf.get_data());\n"
+      "    *uc |= 1 << 7;\n"
+      "    p_buf.put_buf(buf);\n"
+      "  }\n"
+      "  return 0;\n"
+      "}\n\n"
+      , name, unbound_value, dispname);
+    
+    // OER decode
+    src = mputprintf(src,
+      "int %s::OER_decode(const TTCN_Typedescriptor_t&, TTCN_Buffer& p_buf, OER_struct& p_oer)\n"
+      "{\n"
+      "  const unsigned char* uc = p_buf.get_read_data();\n"
+      "  if (!(uc[0] & 0x80)) {\n"
+      "    if (is_valid_enum(uc[0])) {"
+      "       enum_value = static_cast<%s>(uc[0]);\n"
+      "    } else {\n"
+      "      enum_value = %s;\n"
+      "    }\n"
+      "  } else {\n"
+      // This case is the same as decoding a not restricted integer except
+      // the first bit is set to 0
+      "    unsigned char* uc2 = const_cast<unsigned char*>(p_buf.get_read_data());\n"
+      "    uc2[0] &= ~0x80;\n"
+      "    INTEGER intval;\n"
+      "    intval.OER_decode(INTEGER_descr_, p_buf, p_oer);\n"
+      "    if (is_valid_enum(intval.get_val().get_val())) {\n"
+      "      enum_value = static_cast<%s>(intval.get_val().get_val());\n"
+      "    } else {\n"
+      "      enum_value = %s;\n"
+      "    }\n"
+      "  }\n"
+      "  return 0;\n"
+      "}\n\n"
+      , name, enum_type, unknown_value, enum_type, unknown_value);
   }
   /* end of class */
   def = mputstr(def, "};\n\n");
@@ -1242,7 +1321,7 @@ void defEnumTemplate(const enum_def *edef, output_struct *output)
      "TTCN_Logger::log_event_enum(%s::enum_to_str(single_value), single_value);\n"
      "break;\n"
      "case COMPLEMENTED_LIST:\n"
-     "TTCN_Logger::log_event_str(\"complement \");\n"
+     "TTCN_Logger::log_event_str(\"complement\");\n"
      "case VALUE_LIST:\n"
      "TTCN_Logger::log_char('(');\n"
      "for (unsigned int elem_count = 0; elem_count < value_list.n_values; "
