@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -15,6 +15,7 @@
  *   Raduly, Csaba
  *   Szabados, Kristof
  *   Szabo, Janos Zoltan – initial implementation
+ *   Szabo, Bence Janos
  *   Tatarka, Gabor
  *
  ******************************************************************************/
@@ -47,6 +48,9 @@ namespace Ttcn {
   : Node(other)
   , min_v(other.min_v ? other.min_v->clone() : 0)
   , max_v(other.max_v ? other.max_v->clone() : 0)
+  , min_exclusive(other.min_exclusive)
+  , max_exclusive(other.max_exclusive)
+  , type(other.type)
   {}
 
   void ValueRange::set_fullname(const string& p_fullname)
@@ -102,6 +106,10 @@ namespace Ttcn {
     if (min_v) min_v->set_code_section(p_code_section);
     if (max_v) max_v->set_code_section(p_code_section);
   }
+  
+  void ValueRange::set_typetype(Type::typetype_t t) {
+    type = t;
+  }
 
   char *ValueRange::generate_code_init(char *str, const char *name)
   {
@@ -112,11 +120,35 @@ namespace Ttcn {
       min_v->generate_code_expr(&expr);
       init_stmt = mputprintf(init_stmt, "%s.set_min(%s);\n", name, expr.expr);
     }
+    if (min_exclusive) {
+      switch (type) {
+        case Type::T_INT:
+        case Type::T_REAL:
+        case Type::T_CSTR:
+        case Type::T_USTR:
+          init_stmt = mputprintf(init_stmt, "%s.set_min_exclusive(true);\n", name);
+          break;
+        default:
+          FATAL_ERROR("ValueRange::generate_code_init()");
+      }
+    }
     if (max_v) {
       Code::clean_expr(&expr);
       max_v->generate_code_expr(&expr);
       init_stmt = mputprintf(init_stmt, "%s.set_max(%s);\n", name, expr.expr);
     }
+    if (max_exclusive) {
+      switch (type) {
+        case Type::T_INT:
+        case Type::T_REAL:
+        case Type::T_CSTR:
+        case Type::T_USTR:
+          init_stmt = mputprintf(init_stmt, "%s.set_max_exclusive(true);\n", name);
+          break;
+        default:
+          FATAL_ERROR("ValueRange::generate_code_init()");
+      }
+    }
     if (expr.preamble || expr.postamble) {
       str = mputstr(str, "{\n");
       str = mputstr(str, expr.preamble);
@@ -211,6 +243,7 @@ namespace Ttcn {
   // =================================
   
   IndexedTemplate::IndexedTemplate(const IndexedTemplate& p)
+  : Node(p), Location(p)
   {
     index = p.index->clone();
     temp = p.temp->clone();
@@ -325,6 +358,7 @@ namespace Ttcn {
   }
   
   NamedTemplate::NamedTemplate(const NamedTemplate& p)
+  : Node(p), Location(p)
   {
     name = p.name->clone();
     temp = p.temp->clone();
@@ -357,7 +391,7 @@ namespace Ttcn {
   {
     string new_name = name->get_name();
     if (isupper(new_name[0])) {
-      new_name[0] = tolower(new_name[0]);
+      new_name[0] = (char)tolower(new_name[0]);
       if (new_name[new_name.size() - 1] == '_') {
         // an underscore is inserted at the end of the alternative name if it's
         // a basic type's name (since it would conflict with the class generated
@@ -486,6 +520,18 @@ namespace Ttcn {
     range.lower = p_lower;
     range.upper = p_upper;
   }
+  
+  LengthRestriction::LengthRestriction(const LengthRestriction& p)
+    : Node(), checked(p.checked), is_range(p.is_range)
+  {
+    if (is_range) {
+      range.lower = p.range.lower->clone();
+      range.upper = p.range.upper != NULL ? p.range.upper->clone() : NULL;
+    }
+    else {
+      single = p.single->clone();
+    }
+  }
 
   LengthRestriction::~LengthRestriction()
   {
@@ -497,7 +543,7 @@ namespace Ttcn {
 
   LengthRestriction *LengthRestriction::clone() const
   {
-    FATAL_ERROR("LengthRestriction::clone");
+    return new LengthRestriction(*this);
   }
 
   void LengthRestriction::set_fullname(const string& p_fullname)
@@ -708,21 +754,21 @@ namespace Ttcn {
   Value* LengthRestriction::get_single_value()
   {
     if (is_range) FATAL_ERROR("LengthRestriction::get_single_value()");
-    if (!checked) FATAL_ERROR("LengthRestriction::get_single_value()");
+    //if (!checked) FATAL_ERROR("LengthRestriction::get_single_value()");
     return single->get_value_refd_last();
   }
 
   Value *LengthRestriction::get_lower_value()
   {
     if (!is_range) FATAL_ERROR("LengthRestriction::get_lower_value()");
-    if (!checked) FATAL_ERROR("LengthRestriction::get_lower_value()");
+    //if (!checked) FATAL_ERROR("LengthRestriction::get_lower_value()");
     return range.lower->get_value_refd_last();
   }
 
   Value *LengthRestriction::get_upper_value()
   {
     if (!is_range) FATAL_ERROR("LengthRestriction::get_upper_value()");
-    if (!checked) FATAL_ERROR("LengthRestriction::get_upper_value()");
+    //if (!checked) FATAL_ERROR("LengthRestriction::get_upper_value()");
     return range.upper ? range.upper->get_value_refd_last() : 0;
   }
 
