@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -55,7 +55,7 @@ TextAST::TextAST(const TextAST *other_val)
     nof_field_params=other_val->nof_field_params;
     if(nof_field_params) field_params=
       (textAST_enum_def**)Malloc(nof_field_params*sizeof(textAST_enum_def*));
-    for(int a=0;a<nof_field_params;a++){
+    for(size_t a=0;a<nof_field_params;a++){
       if(other_val->field_params[a]){
         field_params[a]=(textAST_enum_def*)Malloc(sizeof(textAST_enum_def));
         field_params[a]->name=
@@ -106,7 +106,8 @@ TextAST::~TextAST()
     Free(separator_val);
   }
   if(field_params){
-    for(int a=0;a<nof_field_params;a++){
+    for(size_t a=0;a<nof_field_params;a++){
+      //TODO: lets extract field_params[a] for speed
       if(field_params[a]){
         delete field_params[a]->name;
         Free(field_params[a]->value.encode_token);
@@ -195,9 +196,9 @@ void TextAST::print_TextAST() const
     else printf("  case_insensitive\n\r");
   }
   else printf("NULL\n\r");
-  printf("Number of fields:%i\n\r",nof_field_params);
-  for(int a=0;a<nof_field_params;a++){
-    printf("Field %i:\n\r",a);
+  printf("Number of fields:%lu\n\r",nof_field_params);
+  for(size_t a=0;a<nof_field_params;a++){
+    printf("Field %lu:\n\r",a);
     if(field_params[a]){
     printf("  Name: %s\n\r",field_params[a]->name->get_name().c_str());
     printf("  Encode token:");
@@ -223,9 +224,9 @@ void TextAST::print_TextAST() const
     printf("  Convert: %i\n\r  Just:%i\n\r",decoding_params.convert,decoding_params.just);
 }
 
-int TextAST::get_field_param_index(const Common::Identifier *name)
+size_t TextAST::get_field_param_index(const Common::Identifier *name)
 {
-  for(int a=0;a<nof_field_params;a++){
+  for(size_t a=0;a<nof_field_params;a++){
     if(*field_params[a]->name==*name) return a;
   }
   field_params=(textAST_enum_def **)Realloc(field_params,(nof_field_params+1)*sizeof(textAST_enum_def *));
@@ -430,7 +431,7 @@ char *make_posix_str_code(const char *pat, bool cs)
   Free(mod_token);
   if (posix_str == NULL) FATAL_ERROR("make_posix_str_code()");
 
-  size_t len = mstrlen(posix_str), skip = 0;
+  size_t len = mstrlen(posix_str);
   if (maybe_fixed) { // maybe we can do fixed strings
     *ret_val = 'F'; // "fixed"
 
@@ -438,6 +439,7 @@ char *make_posix_str_code(const char *pat, bool cs)
     ret_val = mputstrn(ret_val, posix_str + 2, len - 6);
   }
   else { // no fixed-string optimization possible
+    size_t skip = 0;
     // TEXT decoder optimization
     if (len > 3) {
       if (!memcmp(posix_str + (len - 3), ".*$", 3)) {
