@@ -189,7 +189,7 @@ void write_output(output_struct *output, const char *module_name,
   const char *module_dispname, const char *filename_suffix, boolean is_ttcn,
   boolean has_circular_import, boolean is_module)
 {
-    char *header_name, *source_name, *user_info;
+    char *header_name, *source_name, *user_info = NULL;
     FILE *fp;
     boolean is_temporary;
 
@@ -208,7 +208,11 @@ void write_output(output_struct *output, const char *module_name,
 	    duplicate_underscores ? module_name : module_dispname,
 	    filename_suffix);
     }
-    user_info = get_user_info();
+    if (disable_user_info == FALSE) {
+      user_info = get_user_info();
+    } else {
+      user_info = mputstr(user_info, "The generation of user and time information were disabled by the -D flag.\n");
+    }
 
     if (is_module) {
 
@@ -218,12 +222,13 @@ void write_output(output_struct *output, const char *module_name,
 
     fprintf(fp, "// This C++ header file was generated by the %s compiler\n"
 	"// of the TTCN-3 Test Executor version " PRODUCT_NUMBER "\n"
-	"// for %s\n"
+	"// %s%s\n"
 	COPYRIGHT_STRING "\n\n"
 	"// Do not edit this file unless you know what you are doing.\n\n"
 	"#ifndef %s_HH\n"
 	"#define %s_HH\n",
 	is_ttcn ? "TTCN-3" : "ASN.1",
+  disable_user_info == FALSE ? "for " : "",
 	user_info, module_name, module_name);
 
   /* check if the generated code matches the runtime */
@@ -326,10 +331,12 @@ void write_output(output_struct *output, const char *module_name,
 
     fprintf(fp, "// This C++ source file was generated by the %s compiler\n"
 	"// of the TTCN-3 Test Executor version " PRODUCT_NUMBER "\n"
-	"// for %s\n"
+	"// %s%s\n"
 	COPYRIGHT_STRING "\n\n"
 	"// Do not edit this file unless you know what you are doing.\n",
-	is_ttcn ? "TTCN-3" : "ASN.1", user_info);
+	is_ttcn ? "TTCN-3" : "ASN.1", 
+  disable_user_info == FALSE ? "for " : "",
+  user_info);
 
     if (output->source.includes != NULL) {
 	fputs("\n/* Including header files */\n\n", fp);
