@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -23,7 +23,7 @@ static tcov_file_list *the_files = 0;
 static profiler_data_t *the_data = 0;
 
 /** The current database index for the next get_profiler_code_line() call */
-static int current_index = 0;
+static size_t current_index = 0;
 
 /** The file parameter for the last get_profiler_code_line() call */
 static char* last_file_name = 0;
@@ -58,11 +58,10 @@ boolean is_file_profiled(const char* p_file_name)
 }
 
 void insert_profiler_code_line(const char* p_file_name,
-  const char* p_function_name, int p_line_no)
+  const char* p_function_name, size_t p_line_no)
 {
   /* check if the entry already exists */
-  int i;
-  for (i = 0; i < the_data->nof_lines; ++i) {
+  for (size_t i = 0; i < the_data->nof_lines; ++i) {
     if (0 == strcmp(p_file_name,the_data->lines[i].file_name) &&
         p_line_no == the_data->lines[i].line_no) {
       if (0 == the_data->lines[i].function_name && 0 != p_function_name) {
@@ -111,10 +110,9 @@ boolean get_profiler_code_line(const char *p_file_name,
   return FALSE;
 }
 
-void free_profiler_data()
+void free_profiler_data(void)
 {
-  int i;
-  for (i = 0; i < the_data->nof_lines; ++i) {
+  for (size_t i = 0; i < the_data->nof_lines; ++i) {
     Free(the_data->lines[i].file_name);
     Free(the_data->lines[i].function_name);
   }
