@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -161,8 +161,8 @@ ustring::ustring(const string& s)
   bool isUTF8 = true;
   size_t len = s.size();
   for (size_t i = 0; i < len; ++i) {
-    octet_str += Common::hexdigit_to_char((unsigned char)(s[i]) / 16);
-    octet_str += Common::hexdigit_to_char((unsigned char)(s[i]) % 16);
+    octet_str += Common::hexdigit_to_char(static_cast<unsigned char>(s[i]) / 16);
+    octet_str += Common::hexdigit_to_char(static_cast<unsigned char>(s[i]) % 16);
   }
   if (isUTF8) {
     string* ret = Common::get_stringencoding(octet_str);
@@ -172,8 +172,8 @@ ustring::ustring(const string& s)
     delete ret;
   }
   if (isUTF8) {
-    ustring s = Common::decode_utf8(octet_str, CharCoding::UTF_8);
-    val_ptr = s.val_ptr;
+    ustring str = Common::decode_utf8(octet_str, CharCoding::UTF_8);
+    val_ptr = str.val_ptr;
     val_ptr->ref_count++;
   } else {
     init_struct(s.size());
