@@ -36,6 +36,7 @@
 #include "Optional.hh"
 
 #include "../common/dbgnew.hh"
+#include "OER.hh"
 
 // bitstring value class
 
@@ -692,6 +693,12 @@ void BITSTRING::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
     JSON_encode(p_td, tok);
     p_buf.put_s(tok.get_buffer_length(), (const unsigned char*)tok.get_buffer());
     break;}
+  case TTCN_EncDec::CT_OER: {
+    TTCN_EncDec_ErrorContext ec("While OER-encoding type '%s': ", p_td.name);
+    if(!p_td.oer)  TTCN_EncDec_ErrorContext::error_internal(
+      "No OER descriptor available for type '%s'.", p_td.name);
+    OER_encode(p_td, p_buf);
+    break;}
   default:
     TTCN_error("Unknown coding method requested to encode type '%s'",
                p_td.name);
@@ -760,6 +767,13 @@ void BITSTRING::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
                , p_td.name);
     p_buf.set_pos(tok.get_buf_pos());
     break;}
+  case TTCN_EncDec::CT_OER: {
+    TTCN_EncDec_ErrorContext ec("While OER-decoding type '%s': ", p_td.name);
+    if(!p_td.oer)  TTCN_EncDec_ErrorContext::error_internal(
+      "No OER descriptor available for type '%s'.", p_td.name);
+    OER_struct p_oer;
+    OER_decode(p_td, p_buf, p_oer);
+    break;}
   default:
     TTCN_error("Unknown coding method requested to decode type '%s'",
                p_td.name);
@@ -1052,7 +1066,8 @@ int BITSTRING::RAW_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& buff,
   cp.fieldorder = p_td.raw->fieldorder;
   cp.hexorder = ORDER_LSB;
   buff.get_b((size_t) decode_length, val_ptr->bits_ptr, cp, top_bit_ord);
-  if (p_td.raw->length_restrition != -1) {
+  if (p_td.raw->length_restrition != -1 &&
+      decode_length > p_td.raw->length_restrition) {
     val_ptr->n_bits = p_td.raw->length_restrition;
     if (p_td.raw->endianness == ORDER_LSB) {
       if ((decode_length - val_ptr->n_bits) % 8) {
@@ -1264,6 +1279,65 @@ int BITSTRING::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_
   return (int)dec_len;
 }
 
+int BITSTRING::OER_encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf) const {
+  if (!is_bound()) {
+    TTCN_EncDec_ErrorContext::error(TTCN_EncDec::ET_UNBOUND,
+      "Encoding an unbound bitstring value.");
+    return -1;
+  }
+  if (p_td.oer->length == -1) {
+    size_t bytes = 1 + val_ptr->n_bits / 8;
+    int rem = (val_ptr->n_bits % 8);
+    if (rem != 0) {
+      bytes++;
+    }
+    encode_oer_length(bytes, p_buf, FALSE);
+    p_buf.put_c(rem == 0 ? 0 : 8 - rem);
+  }
+  char c = 0;
+  int pos = 8;
+  for (int i = 0; i < val_ptr->n_bits; i++) {
+    pos--;
+    c += get_bit(i) << pos;
+    if (pos == 0) {
+      p_buf.put_c(c);
+      c = 0;
+      pos = 8;
+    }
+  }
+  if (pos != 8) {
+    p_buf.put_c(c);
+  }
+  return 0;
+}
+
+int BITSTRING::OER_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf, OER_struct&) {
+  
+  size_t bytes;
+  if (p_td.oer->length == -1) {
+    bytes = decode_oer_length(p_buf, FALSE) - 1;
+    const unsigned char* uc = p_buf.get_read_data();
+    init_struct((bytes * 8) - uc[0]);
+    p_buf.increase_pos(1);
+  } else {
+    bytes = p_td.oer->length / 8;
+    if (p_td.oer->length % 8 != 0) {
+      bytes++;
+    }
+    init_struct(p_td.oer->length);
+  }
+
+  const unsigned char* uc = p_buf.get_read_data();
+  int bit_pos = 0;
+  for (size_t i = 0; i < bytes; i++) {
+    for (int j = 7; j >= 0 && bit_pos < val_ptr->n_bits; j--) {
+      set_bit(bit_pos, (uc[i] & (1 << j)));
+      bit_pos++;
+    }
+  }
+  p_buf.increase_pos(bytes);
+  return 0;
+}
 
 // bitstring element class
 
@@ -2150,7 +2224,7 @@ void BITSTRING_template::log() const
     single_value.log();
     break;
   case COMPLEMENTED_LIST:
-    TTCN_Logger::log_event_str("complement ");
+    TTCN_Logger::log_event_str("complement");
     // no break
   case VALUE_LIST:
     TTCN_Logger::log_char('(');
