@@ -33,6 +33,7 @@
 #include "Encdec.hh"
 #include "RAW.hh"
 #include "BER.hh"
+#include "OER.hh"
 #include "TEXT.hh"
 #include "Charstring.hh"
 #include "XmlReader.hh"
@@ -249,6 +250,12 @@ void BOOLEAN::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
     JSON_encode(p_td, tok);
     p_buf.put_s(tok.get_buffer_length(), (const unsigned char*)tok.get_buffer());
     break;}
+  case TTCN_EncDec::CT_OER: {
+    TTCN_EncDec_ErrorContext ec("While OER-encoding type '%s': ", p_td.name);
+    if(!p_td.oer)  TTCN_EncDec_ErrorContext::error_internal(
+      "No OER descriptor available for type '%s'.", p_td.name);
+    OER_encode(p_td, p_buf);
+    break;}
   default:
     TTCN_error("Unknown coding method requested to encode type '%s'",
                p_td.name);
@@ -334,6 +341,13 @@ void BOOLEAN::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
                , p_td.name);
     p_buf.set_pos(tok.get_buf_pos());
     break;}
+  case TTCN_EncDec::CT_OER: {
+    TTCN_EncDec_ErrorContext ec("While OER-decoding type '%s': ", p_td.name);
+    if(!p_td.oer)  TTCN_EncDec_ErrorContext::error_internal(
+      "No OER descriptor available for type '%s'.", p_td.name);
+    OER_struct p_oer;
+    OER_decode(p_td, p_buf, p_oer);
+    break;}
   default:
     TTCN_error("Unknown coding method requested to decode type '%s'",
                p_td.name);
@@ -687,7 +701,7 @@ int BOOLEAN::XER_decode(const XERdescriptor_t& p_td, XmlReaderWrap& reader,
             TTCN_EncDec::ET_INVAL_MSG, "Boolean must be empty element");
           value = (const char*)reader.LocalName();
         }
-        else if (XML_READER_TYPE_TEXT == type) {
+        else if (XML_READER_TYPE_TEXT == type || XML_READER_TYPE_ATTRIBUTE == type) {
           // TextBoolean
           value = (const char*)reader.Value();
         }
@@ -778,6 +792,34 @@ int BOOLEAN::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_to
   return (int)dec_len;
 }
 
+int BOOLEAN::OER_encode(const TTCN_Typedescriptor_t&, TTCN_Buffer& p_buf) const
+{
+  if (!is_bound()) {
+    TTCN_EncDec_ErrorContext::error(TTCN_EncDec::ET_UNBOUND,
+      "Encoding an unbound boolean value.");
+    return -1;
+  }
+  if (boolean_value) {
+    p_buf.put_c(255); // FF
+  } else {
+    p_buf.put_c(0); // 00
+  }
+  return 1;
+}
+
+int BOOLEAN::OER_decode(const TTCN_Typedescriptor_t&, TTCN_Buffer& p_buf, OER_struct&)
+{
+  const unsigned char* c = p_buf.get_read_data();
+  p_buf.increase_pos(1);
+  if (*c == 0) {
+    boolean_value = FALSE;
+  } else {
+    boolean_value = TRUE;
+  }
+  bound_flag = TRUE;
+  return 1;
+}
+
 
 boolean operator&&(boolean bool_value, const BOOLEAN& other_value)
 {
@@ -1012,7 +1054,7 @@ void BOOLEAN_template::log() const
     TTCN_Logger::log_event_str(single_value ? "true" : "false");
     break;
   case COMPLEMENTED_LIST:
-    TTCN_Logger::log_event_str("complement ");
+    TTCN_Logger::log_event_str("complement");
     // no break
   case VALUE_LIST:
     TTCN_Logger::log_char('(');
