@@ -434,7 +434,7 @@ void DEFAULT_template::log() const
     TTCN_Default::log(single_value);
     break;
   case COMPLEMENTED_LIST:
-    TTCN_Logger::log_event_str("complement ");
+    TTCN_Logger::log_event_str("complement");
     // no break
   case VALUE_LIST:
     TTCN_Logger::log_char('(');
@@ -728,7 +728,7 @@ void TTCN_Default::restore_control_defaults()
   if (!control_defaults_saved)
     TTCN_error("Internal error: Control part defaults are not saved.");
   if (list_head != NULL)
-    TTCN_error("Internal error: There are defaults timers. "
+    TTCN_error("Internal error: There are active defaults. "
       "Control part defaults cannot be restored.");
   // restore the list of control part defaults from the backup
   list_head = backup_head;
