@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -200,7 +200,7 @@ void Module_List::set_param(Module_Param& param)
     }
 #endif
     
-    param.get_id()->next_name(-1); // set the position back to the first segment
+    param.get_id()->reset(); // set the position back to the first segment
     for (TTCN_Module *list_iter = list_head; list_iter != NULL;
       list_iter = list_iter->list_next) {
       if (list_iter->set_param_func != NULL &&
@@ -250,7 +250,7 @@ Module_Param* Module_List::get_param(Module_Param_Name& param_name,
   // If not found, check if the first name segment was the module parameter name
   // (even if it matched a module name)
   if (param == NULL) {
-    param_name.next_name(-1); // set the position back to the first segment
+    param_name.reset(); // set the position back to the first segment
     for (TTCN_Module *list_iter = list_head; list_iter != NULL;
       list_iter = list_iter->list_next) {
       if (list_iter->get_param_func != NULL) {
@@ -349,8 +349,9 @@ void Module_List::print_version()
     "--------------------\n", stderr);
 }
 
-void Module_List::send_versions() {
 #ifdef USAGE_STATS
+void Module_List::send_usage_stats(pthread_t& thread, thread_data*& data)
+{
   std::set<ModuleVersion> versions;
   for (TTCN_Module *list_iter = list_head; list_iter != NULL;
       list_iter = list_iter->list_next)  {
@@ -371,11 +372,26 @@ void Module_List::send_versions() {
       }
   }
 
-  HttpSender* sender = new HttpSender;
-  UsageData::getInstance().sendDataThreaded(stream.str().c_str(), sender);
-#endif
+  data = new thread_data;
+  data->sndr = new HttpSender;
+  thread = UsageData::getInstance().sendDataThreaded(stream.str().c_str(), data);
 }
-            
+
+void Module_List::clean_up_usage_stats(pthread_t thread, thread_data* data)
+{
+  if (thread != 0) {
+    // cancel the usage stats thread if it hasn't finished yet
+    pthread_cancel(thread);
+    pthread_join(thread, NULL);
+  }
+  if (data != NULL) {
+    if (data->sndr != NULL) {
+      delete data->sndr;
+    }
+    delete data;
+  }
+}
+#endif // USAGE_STATS   
 
 void Module_List::list_testcases()
 {
@@ -925,7 +941,7 @@ void TTCN_Module::post_init_module()
   post_init_called = TRUE;
   TTCN_Logger::log_module_init(module_name);
   if (post_init_func != NULL) post_init_func();
-  TTCN_Logger::log_module_init(module_name, true);
+  TTCN_Logger::log_module_init(module_name, TRUE);
 }
 
 void TTCN_Module::add_function(const char *function_name,
