@@ -37,6 +37,7 @@
 #include "Optional.hh"
 
 #include "../common/dbgnew.hh"
+#include "OER.hh"
 #include <string.h>
 #include <ctype.h>
 
@@ -653,6 +654,12 @@ void OCTETSTRING::encode(const TTCN_Typedescriptor_t& p_td,
     JSON_encode(p_td, tok);
     p_buf.put_s(tok.get_buffer_length(), (const unsigned char*)tok.get_buffer());
     break;}
+  case TTCN_EncDec::CT_OER: {
+    TTCN_EncDec_ErrorContext ec("While OER-encoding type '%s': ", p_td.name);
+    if(!p_td.oer)  TTCN_EncDec_ErrorContext::error_internal(
+      "No OER descriptor available for type '%s'.", p_td.name);
+    OER_encode(p_td, p_buf);
+    break;}
   default:
     TTCN_error("Unknown coding method requested to encode type '%s'",
                p_td.name);
@@ -740,6 +747,13 @@ void OCTETSTRING::decode(const TTCN_Typedescriptor_t& p_td,
                , p_td.name);
     p_buf.set_pos(tok.get_buf_pos());
     break;}
+  case TTCN_EncDec::CT_OER: {
+      TTCN_EncDec_ErrorContext ec("While OER-decoding type '%s': ", p_td.name);
+    if(!p_td.oer)  TTCN_EncDec_ErrorContext::error_internal(
+      "No OER descriptor available for type '%s'.", p_td.name);
+    OER_struct p_oer;
+    OER_decode(p_td, p_buf, p_oer);
+    break;}
   default:
     TTCN_error("Unknown coding method requested to decode type '%s'",
                p_td.name);
@@ -794,6 +808,15 @@ int OCTETSTRING::JSON_encode_negtest_raw(JSON_Tokenizer& p_tok) const
   }
   return 0;
 }
+
+int OCTETSTRING::OER_encode_negtest_raw(TTCN_Buffer& p_buf) const
+{
+  if (val_ptr != NULL) {
+    p_buf.put_os(*this);
+    return val_ptr->n_octets;
+  }
+  return 0;
+}
 #endif
 
 boolean OCTETSTRING::BER_decode_TLV(const TTCN_Typedescriptor_t& p_td,
@@ -1261,7 +1284,8 @@ int OCTETSTRING::RAW_decode(const TTCN_Typedescriptor_t& p_td,
   init_struct(decode_length / 8);
   buff.get_b((size_t) decode_length, val_ptr->octets_ptr, cp, top_bit_ord);
 
-  if (p_td.raw->length_restrition != -1) {
+  if (p_td.raw->length_restrition != -1 &&
+      decode_length > p_td.raw->length_restrition) {
     val_ptr->n_octets = p_td.raw->length_restrition;
     if (p_td.raw->endianness == ORDER_MSB) memmove(val_ptr->octets_ptr,
       val_ptr->octets_ptr + (decode_length / 8 - val_ptr->n_octets),
@@ -1388,6 +1412,36 @@ int OCTETSTRING::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer&
   return (int)dec_len;
 }
 
+int OCTETSTRING::OER_encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf) const {
+  if (!is_bound()) {
+    TTCN_EncDec_ErrorContext::error(TTCN_EncDec::ET_UNBOUND,
+      "Encoding an unbound octetstring value.");
+    return -1;
+  }
+  if (p_td.oer->length == -1) {
+    encode_oer_length(lengthof(), p_buf, FALSE);
+  }
+  p_buf.put_os(*this);
+  return 0;
+}
+  
+
+int OCTETSTRING::OER_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf, OER_struct&) {
+  size_t bytes;
+  if (p_td.oer->length == -1) {
+    bytes = decode_oer_length(p_buf, FALSE);
+  } else {
+    bytes = p_td.oer->length;
+  }
+  init_struct(bytes);
+  const unsigned char* uc = p_buf.get_read_data();
+  for (size_t i = 0; i < bytes; i++) {
+    val_ptr->octets_ptr[i] = uc[i];
+  }
+  p_buf.increase_pos(bytes);
+  return 0;
+}
+
 // octetstring element class
 
 OCTETSTRING_ELEMENT::OCTETSTRING_ELEMENT(boolean par_bound_flag,
@@ -2278,7 +2332,7 @@ void OCTETSTRING_template::log() const
     single_value.log();
     break;
   case COMPLEMENTED_LIST:
-    TTCN_Logger::log_event_str("complement ");
+    TTCN_Logger::log_event_str("complement");
     // no break
   case VALUE_LIST:
     TTCN_Logger::log_char('(');
