@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -273,10 +273,9 @@ void TTCN3_Profiler::enter_function(const char* filename, int lineno)
   execute_line(filename, lineno);
   
   if (!stopped) {
-    int element = get_element(filename);
-
     // store function data
     if (!disable_coverage) {
+      unsigned int element = get_element(filename);
       ++profiler_db[element].functions[get_function(element, lineno)].exec_count;
     }
   }
@@ -310,7 +309,7 @@ void TTCN3_Profiler::execute_line(const char* filename, int lineno)
     // also, several instructions could be in the same line, only count the line once
     if (0 != lineno && !disable_coverage && (lineno != prev_line || NULL == prev_file || 
                                              0 != strcmp(prev_file, filename))) {
-      int element = get_element(filename);
+      unsigned int element = get_element(filename);
 
       // increase line execution count
       ++profiler_db[element].lines[get_line(element, lineno)].exec_count;
@@ -321,7 +320,7 @@ void TTCN3_Profiler::execute_line(const char* filename, int lineno)
   set_prev(disable_profiler ? -1 : TTCN3_Stack_Depth::depth(), filename, lineno);
 }
 
-int TTCN3_Profiler::get_element(const char* filename) 
+unsigned int TTCN3_Profiler::get_element(const char* filename) 
 {
   for (size_t i = 0; i < profiler_db.size(); ++i) {
     if (0 == strcmp(profiler_db[i].filename, filename)) {
@@ -335,27 +334,27 @@ int TTCN3_Profiler::get_element(const char* filename)
   return profiler_db.size() - 1;
 }
 
-int TTCN3_Profiler::get_function(int element, int lineno)
+int TTCN3_Profiler::get_function(unsigned int element, int lineno)
 {
   return Profiler_Tools::get_function(profiler_db, element, lineno);
 }
 
-void TTCN3_Profiler::create_function(int element, int lineno, const char* function_name)
+void TTCN3_Profiler::create_function(unsigned int element, int lineno, const char* function_name)
 {
   Profiler_Tools::create_function(profiler_db, element, lineno, function_name);
 }
 
-int TTCN3_Profiler::get_line(int element, int lineno)
+int TTCN3_Profiler::get_line(unsigned int element, int lineno)
 {
   return Profiler_Tools::get_line(profiler_db, element, lineno);
 }
 
-void TTCN3_Profiler::create_line(int element, int lineno)
+void TTCN3_Profiler::create_line(unsigned int element, int lineno)
 {
   Profiler_Tools::create_line(profiler_db, element, lineno);
 }
 
-void TTCN3_Profiler::add_line_time(timeval elapsed, int element, int lineno) 
+void TTCN3_Profiler::add_line_time(timeval elapsed, unsigned int element, int lineno) 
 {
   if (0 == lineno) {
     return;
@@ -364,7 +363,7 @@ void TTCN3_Profiler::add_line_time(timeval elapsed, int element, int lineno)
     profiler_db[element].lines[get_line(element, lineno)].total_time, elapsed);
 }
 
-void TTCN3_Profiler::add_function_time(timeval elapsed, int element, int lineno)
+void TTCN3_Profiler::add_function_time(timeval elapsed, unsigned int element, int lineno)
 {
   int func = get_function(element, lineno);
   if (-1 == func) {
@@ -382,7 +381,7 @@ void TTCN3_Profiler::update_last()
 
   timeval elapsed = Profiler_Tools::subtract_timeval(get_time(), prev_time);
 
-  int element = get_element(prev_file);
+  unsigned int element = get_element(prev_file);
   
   // add the elapsed time to the total time of the previous line
   add_line_time(elapsed, element, prev_line);
@@ -454,22 +453,22 @@ void TTCN3_Stack_Depth::add_stack(int stack_len, const char* caller_file, const
   item.start_line = start_line;
   item.elapsed.tv_sec = 0;
   item.elapsed.tv_usec = 0;
-  item.first_call = true;
-  item.recursive_call = false;
+  item.first_call = TRUE;
+  item.recursive_call = FALSE;
 
   if (!net_line_times || !net_func_times) {
     // check if it's a recursive function
     for (int i = current_depth - 1; i >= 0 ; --i) {
       if (call_stack_timer_db[i].start_line == start_line &&
           0 == strcmp(call_stack_timer_db[i].func_file, func_file)) {
-        item.recursive_call = true;
+        item.recursive_call = TRUE;
 
         // check if the caller is new
         if (call_stack_timer_db[i].caller_line == caller_line &&
             ((NULL == call_stack_timer_db[i].caller_file && NULL == caller_file) ||
              (NULL != call_stack_timer_db[i].caller_file && NULL != caller_file &&
              0 == strcmp(call_stack_timer_db[i].caller_file, caller_file)))) {
-          item.first_call = false;
+          item.first_call = FALSE;
           break;
         }
       }
