@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -1219,7 +1219,7 @@ boolean match_record_of(const Base_Type *value_ptr, int value_size,
   // permutation
   if (nof_permutations == 1 && template_ptr->get_permutation_start(0) == 0 &&
     template_ptr->get_permutation_end(0) ==
-      (unsigned int)(template_size - 1))
+      static_cast<unsigned int>(template_size - 1) )
     return match_set_of(value_ptr, value_size, template_ptr, template_size,
       match_function, legacy);
 
@@ -1305,7 +1305,7 @@ void log_match_heuristics(const Base_Type *value_ptr, int value_size,
 
   boolean value_found = FALSE;
   int nof_unmatched_values = 0;
-  bool *unmatched_values = new bool[value_size];
+  boolean *unmatched_values = new bool[value_size];
   for (int i = 0; i < value_size; i++)
   {
     boolean pair_found = FALSE;
@@ -1342,7 +1342,7 @@ void log_match_heuristics(const Base_Type *value_ptr, int value_size,
 
   boolean template_found = FALSE;
   int nof_unmatched_templates = 0;
-  bool *unmatched_templates = new bool[template_size];
+  boolean *unmatched_templates = new bool[template_size];
   for (int i = 0; i < template_size; i++)
   {
     boolean pair_found = FALSE;
