@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *   Balasko, Jeno
+ *   Baranyi, Botond
  *   Delic, Adam
  *   Kovacs, Ferenc
  *   Raduly, Csaba
@@ -18,6 +19,7 @@
 #include "Error.hh"
 #include "Logger.hh"
 #include "Snapshot.hh"
+#include "Basetype.hh"
 
 TIMER *TIMER::list_head = NULL, *TIMER::list_tail = NULL,
     *TIMER::backup_head = NULL, *TIMER::backup_tail = NULL;
@@ -185,13 +187,13 @@ double TIMER::read() const
   return ret_val;
 }
 
-boolean TIMER::running() const
+boolean TIMER::running(Index_Redirect*) const
   {
   // the time is not frozen (i.e. time_now() is used)
   return is_started && TTCN_Snapshot::time_now() < t_expires;
   }
 
-alt_status TIMER::timeout()
+alt_status TIMER::timeout(Index_Redirect*)
 {
   // the time is frozen (i.e. get_alt_begin() is used)
   if (is_started) {
