@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,6 +12,7 @@
  *   Forstner, Matyas
  *   Kovacs, Ferenc
  *   Raduly, Csaba
+ *   Szabo, Bence Janos
  *   Szabo, Janos Zoltan – initial implementation
  *   Zalanyi, Balazs Andor
  *
@@ -42,7 +43,7 @@ typedef bool boolean;
 #define TRUE true
 
 enum verdicttype { NONE = 0, PASS = 1, INCONC = 2, FAIL = 3, ERROR = 4 };
-extern const char * const verdict_name[];
+extern const char * const verdict_name[5];
 
 enum alt_status { ALT_UNCHECKED, ALT_YES, ALT_MAYBE, ALT_NO, ALT_REPEAT,
     ALT_BREAK };
@@ -54,7 +55,7 @@ enum asn_null_type { ASN_NULL_VALUE };
 struct universal_char {
   unsigned char uc_group, uc_plane, uc_row, uc_cell;
 
-  bool is_char() const {
+  boolean is_char() const {
     return uc_group == 0 && uc_plane == 0 && uc_row == 0 && uc_cell < 128;
   }
 };
@@ -128,4 +129,13 @@ struct namespace_t {
   const char * const px;
 };
 
+// States defined with the setstate operation.
+enum translation_port_state {
+  UNSET = -1,
+  TRANSLATED = 0,
+  NOT_TRANSLATED = 1,
+  FRAGMENTED = 2,
+  PARTIALLY_TRANSLATED = 3
+};
+
 #endif
