@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -308,7 +308,7 @@ void Cli::notify(const struct timeval *timestamp, const char *source,
         fflush(stdout);
         break;
       case TSF_SEC:
-        printf("%ld.%06ld %s: %s\n", (long)timestamp->tv_sec, timestamp->tv_usec, source, message);
+        printf("%ld.%06ld %s: %s\n", static_cast<long>( timestamp->tv_sec ), timestamp->tv_usec, source, message);
         fflush(stdout);
       
         break;
@@ -336,7 +336,7 @@ void Cli::printWelcome()
     "*************************************************************************\n"
     "* TTCN-3 Test Executor - Main Controller 2                              *\n"
     "* Version: %-40s                     *\n"
-    "* Copyright (c) 2000-2016 Ericsson Telecom AB                           *\n"
+    "* Copyright (c) 2000-2017 Ericsson Telecom AB                           *\n"
     "* All rights reserved. This program and the accompanying materials      *\n"
     "* are made available under the terms of the Eclipse Public License v1.0 *\n"
     "* which accompanies this distribution, and is available at              *\n"
