@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2016 Ericsson Telecom AB
+ * Copyright (c) 2000-2017 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -23,7 +23,7 @@
 // Author:                Vilmos Varga
 // mail:                  ethvva@eth.ericsson.se
 //
-// Copyright (c) 2000-2016 Ericsson Telecom AB
+// Copyright (c) 2000-2017 Ericsson Telecom AB
 //
 //----------------------------------------------------------------------------
 
@@ -49,6 +49,8 @@
 #include "../../common/license.h"
 #endif
 
+#include "../../common/openssl_version.h"
+
 #include "MainController.h"
 
 #if defined CLI
@@ -273,12 +275,12 @@ int main(int argc, char *argv[])
       " for the TTCN-3 Test Executor\n"
       "Product number: " PRODUCT_NUMBER "\n"
       "Build date: " __DATE__ " " __TIME__ "\n"
-      "Compiled with: " C_COMPILER_VERSION "\n\n"
-      COPYRIGHT_STRING "\n\n", stderr);
+      "Compiled with: " C_COMPILER_VERSION "\n", stderr);
+    fputs("Using ", stderr);
+    fputs(openssl_version_str(), stderr);
+    fputs("\n\n" COPYRIGHT_STRING "\n\n", stderr);
 #ifdef LICENSE
     print_license_info();
-    fputs("\nUsing ", stderr);
-    fputs(openssl_version_str(), stderr);
     fputs("\n\n", stderr);
 #endif
     return 0;
