@@ -1,6 +1,6 @@
 #!/usr/bin/perl -wl
 ###############################################################################
-# Copyright (c) 2000-2016 Ericsson Telecom AB
+# Copyright (c) 2000-2017 Ericsson Telecom AB
 # All rights reserved. This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v1.0
 # which accompanies this distribution, and is available at
@@ -46,6 +46,10 @@ while (<>)
   elsif (/Looks like/) {
     push @output, "$_ in $dirname";
   }
+  elsif (/(\S+:\d+:\s+)?Memory leak at \S+, size \d+, ord \d+:.*/)
+  {
+    push @output, $dirname.": ".$_;
+  }
 }
 
 my $errorCount = 0;
