@@ -21,6 +21,7 @@
 #include "TTCN3Module.hh"
 #include "TTCN3ModuleInventory.hh"
 #include "Annotation.hh"
+#include "Constant.hh"
 
 #include <assert.h>
 
@@ -41,7 +42,6 @@ ComplexType::ComplexType(XMLParser * a_parser, TTCN3Module * a_module, Construct
 , lastType()
 , actualPath(empty_string)
 , actfield(this)
-, nameDep(NULL)
 , nillable_field(NULL)
 , basefield(NULL)
 , cmode(CT_undefined_mode)
@@ -71,7 +71,6 @@ ComplexType::ComplexType(ComplexType & other)
 , lastType(other.lastType)
 , actualPath(other.actualPath)
 , actfield(this)
-, nameDep(other.nameDep)
 , nillable_field(NULL)
 , basefield(NULL)
 , cmode(other.cmode)
@@ -121,7 +120,6 @@ ComplexType::ComplexType(ComplexType * other)
 , lastType()
 , actualPath(empty_string)
 , actfield(this)
-, nameDep(NULL)
 , nillable_field(NULL)
 , basefield(NULL)
 , cmode(CT_undefined_mode)
@@ -153,7 +151,6 @@ ComplexType::ComplexType(const SimpleType & other, CT_fromST c)
 , lastType()
 , actualPath(empty_string)
 , actfield(this)
-, nameDep(NULL)
 , nillable_field(NULL)
 , basefield(NULL)
 , cmode(CT_simpletype_mode)
@@ -164,12 +161,12 @@ ComplexType::ComplexType(const SimpleType & other, CT_fromST c)
 , enumfields()
 , tagNames() {
 
-  if(c != fromTagSubstitution && c != fromTypeSubstitution){
+  if(c != fromElementSubstitution && c != fromTypeSubstitution){
     module->replaceLastMainType(this);
     module->setActualXsdConstruct(c_complexType);
   }
   construct = c_complexType;
-
+  
   switch (c) {
     case fromTagUnion:
       type.upload(Mstring("union"), false);
@@ -184,7 +181,7 @@ ComplexType::ComplexType(const SimpleType & other, CT_fromST c)
       type.upload(Mstring("record"), false);
       xsdtype = n_complexType;
       break;
-    case fromTagSubstitution:
+    case fromElementSubstitution:
       type.upload(Mstring("union"), false);
       name.upload(getName().originalValueWoPrefix + Mstring("_group"));
       xsdtype = n_union;
@@ -196,6 +193,7 @@ ComplexType::ComplexType(const SimpleType & other, CT_fromST c)
       pattern.modified = false;
       length.modified = false;
       whitespace.modified = false;
+      new_construct = c_complexType;
       break;
     case fromTypeSubstitution:
       type.upload(Mstring("union"), false);
@@ -210,6 +208,7 @@ ComplexType::ComplexType(const SimpleType & other, CT_fromST c)
       pattern.modified = false;
       length.modified = false;
       whitespace.modified = false;
+      new_construct = c_complexType;
   }
 }
 
@@ -345,10 +344,12 @@ void ComplexType::loadWithValues() {
         if(cmode == CT_simpletype_mode){
           //If a simple top level element is nillable
           ComplexType * nilrec = new ComplexType(this);
+          nilrec->xsdtype = n_element;
           if (atts.type.empty()) {
             nilrec->type.upload(Mstring("record"), false);
           } else {
             nilrec->type.upload(atts.type);
+            nilrec->setReference(atts.type);
           }
           nilrec->name.upload(Mstring("content"));
           nilrec->isOptional = true;
@@ -363,10 +364,12 @@ void ComplexType::loadWithValues() {
           //From a complexType element is nillable
           ComplexType * record = new ComplexType(this);
           ComplexType * nilrec = new ComplexType(record);
+          nilrec->xsdtype = n_element;
           if (atts.type.empty()) {
             nilrec->type.upload(Mstring("record"), false);
           } else {
             nilrec->type.upload(atts.type);
+            nilrec->setReference(atts.type);
           }
           record->name.upload(atts.name);
           record->type.upload(Mstring("record"), false);
@@ -723,7 +726,7 @@ void ComplexType::referenceResolving() {
   }
   resolved = InProgress;
   for (List<ComplexType*>::iterator ct = complexfields.begin(); ct; ct = ct->Next) {
-    // Referenece resolving of ComplexTypes
+    // Reference resolving of ComplexTypes
     ct->Data->referenceResolving();
   }
   for (List<AttributeType*>::iterator attr = attribfields.begin(); attr; attr = attr->Next) {
@@ -750,20 +753,11 @@ void ComplexType::reference_resolving_funtion() {
     return;
   }
 
-  SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(this, want_BOTH);
-  if (st == NULL && basefield == NULL) {
-    printError(module->getSchemaname(), name.convertedValue,
-      "Reference for a non-defined type: " + getReference().repr());
-    TTCN3ModuleInventory::getInstance().incrNumErrors();
-    outside_reference.set_resolved(NULL);
-    return;
-  }
+  resolveAttributeGroup();
 
-  resolveAttributeGroup(st);
+  resolveGroup();
 
-  resolveGroup(st);
-
-  resolveElement(st);
+  resolveElement();
 
   resolveSimpleTypeExtension();
 
@@ -773,7 +767,7 @@ void ComplexType::reference_resolving_funtion() {
 
   resolveComplexTypeRestriction();
 
-  resolveUnion(st);
+  resolveUnion();
 
   addToTypeSubstitutions();
 
@@ -859,7 +853,8 @@ void ComplexType::nameConversion_names(const List<NamespaceType> &) {
       break;
     }
   }
-  if (!found) {
+  // element or type substitution generated types do not need 'name as' variant
+  if (!found && subsGroup != this && typeSubsGroup != this) {
     addVariant(V_onlyValue, var);
   }
   for (List<RootType*>::iterator dep = nameDepList.begin(); dep; dep = dep->Next) {
@@ -1097,11 +1092,6 @@ void ComplexType::subFinalModification() {
       delete field->Data;
       field->Data = NULL;
       attribfields.remove(field);
-    } else if (field->Data->getUseVal() == prohibited || !field->Data->isVisible()) {
-      //Not visible attribute removed
-      delete field->Data;
-      field->Data = NULL;
-      attribfields.remove(field);
     } else {
       field->Data->SimpleType::finalModification();
     }
@@ -1144,8 +1134,16 @@ void ComplexType::subFinalModification2() {
     //Recursive call
     field->Data->subFinalModification2();
   }
-  for (List<AttributeType*>::iterator field = attribfields.begin(); field; field = field->Next) {
-    field->Data->SimpleType::finalModification2();
+  for (List<AttributeType*>::iterator field = attribfields.begin(), nextField; field; field = nextField) {
+    nextField = field->Next;
+    if (field->Data->getUseVal() == prohibited || !field->Data->isVisible()) {
+      //Not visible attribute removed
+      delete field->Data;
+      field->Data = NULL;
+      attribfields.remove(field);
+    } else {
+      field->Data->SimpleType::finalModification2();
+    }
   }
 }
 
@@ -1697,14 +1695,17 @@ void ComplexType::addNameSpaceAsVariant(RootType * root, RootType * other) {
 
 void ComplexType::resolveAttribute(AttributeType* attr) {
   if (attr->getXsdtype() == n_attribute && !attr->getReference().empty()) {
-    SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(attr, want_BOTH);
+    ConstructType type_construct = attr->isFromRef() ? c_attribute : c_simpleType;
+    SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(attr, want_BOTH, type_construct);
     if (st != NULL) {
+      attr->setBuiltInBase(st->getBuiltInBase());
       if (attr->isFromRef()) {
         addNameSpaceAsVariant(attr, st);
         attr->setTypeOfField(st->getName().convertedValue);
         attr->setNameOfField(st->getName().originalValueWoPrefix);
         attr->setOrigModule(st->getModule());
         st->addToNameDepList(attr);
+        attr->nameDep = st;
         if (attr->getConstantDefaultForEmpty() != NULL) {
           st->addToNameDepList((RootType*)attr->getConstantDefaultForEmpty());
         }
@@ -1714,6 +1715,7 @@ void ComplexType::resolveAttribute(AttributeType* attr) {
             || st->getXsdtype() == n_NOTSET) // It really is a simpleType
           {
             st->addToNameDepList(attr);
+            attr->nameDep = st;
             if (attr->getConstantDefaultForEmpty() != NULL) {
               st->addToNameDepList((RootType*)attr->getConstantDefaultForEmpty());
             }
@@ -1722,14 +1724,22 @@ void ComplexType::resolveAttribute(AttributeType* attr) {
       attr->getReference().set_resolved(st);
     } else {
       printError(module->getSchemaname(), name.convertedValue,
-        "Reference for a non-defined type: " + attr->getReference().repr());
+        "Reference for a non-defined attribute or simpleType type: " + attr->getReference().repr());
       TTCN3ModuleInventory::getInstance().incrNumErrors();
     }
   }
 }
 
-void ComplexType::resolveAttributeGroup(SimpleType * st) {
+void ComplexType::resolveAttributeGroup() {
   if (xsdtype == n_attributeGroup && !outside_reference.empty()) {
+    SimpleType* st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(this, want_BOTH, c_attributeGroup);
+    if (st == NULL && basefield == NULL) {
+      printError(module->getSchemaname(), name.convertedValue,
+        "Reference for a non-defined attributeGroup type: " + getReference().repr());
+      TTCN3ModuleInventory::getInstance().incrNumErrors();
+      outside_reference.set_resolved(NULL);
+      return;
+    }
     ComplexType * ct = (ComplexType*) st;
     if(ct->resolved == No){
       ct->referenceResolving();
@@ -1782,8 +1792,16 @@ void ComplexType::resolveAttributeGroup(SimpleType * st) {
   }
 }
 
-void ComplexType::resolveGroup(SimpleType *st) {
+void ComplexType::resolveGroup() {
   if (xsdtype == n_group && !outside_reference.empty()) {
+    SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(this, want_BOTH, c_group);
+    if (st == NULL && basefield == NULL) {
+      printError(module->getSchemaname(), name.convertedValue,
+        "Reference for a non-defined group type: " + getReference().repr());
+      TTCN3ModuleInventory::getInstance().incrNumErrors();
+      outside_reference.set_resolved(NULL);
+      return;
+    }
     ComplexType * ct = (ComplexType*) st;
     outside_reference.set_resolved(ct);
     setInvisible();
@@ -1837,8 +1855,17 @@ void ComplexType::resolveGroup(SimpleType *st) {
   }
 }
 
-void ComplexType::resolveElement(SimpleType *st) {
+void ComplexType::resolveElement() {
   if (xsdtype == n_element && !outside_reference.empty()) {
+    ConstructType type_construct = fromRef ? c_element : c_simpleOrComplexType;
+    SimpleType* st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(this, want_BOTH, type_construct);
+    if (st == NULL && basefield == NULL) {
+      printError(module->getSchemaname(), name.convertedValue,
+        "Reference for a non-defined element or simpleType or complexType type: " + getReference().repr());
+      TTCN3ModuleInventory::getInstance().incrNumErrors();
+      outside_reference.set_resolved(NULL);
+      return;
+    }
     outside_reference.set_resolved(st);
     type.upload(st->getModule()->getTargetNamespaceConnector() + Mstring(":") + st->getName().convertedValue);
     if (name.originalValueWoPrefix.empty()) {
@@ -1875,7 +1902,8 @@ void ComplexType::resolveElement(SimpleType *st) {
 
 void ComplexType::resolveSimpleTypeExtension() {
   if (mode == extensionMode && cmode == CT_simpletype_mode && basefield != NULL) {
-    SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(basefield, want_BOTH);
+    SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(basefield, want_BOTH, c_simpleOrComplexType);
+    
     if (st != NULL) {
       if (st->getXsdtype() != n_NOTSET && ((ComplexType*) st)->basefield != NULL) { // if the xsdtype != simpletype
         ComplexType * ct = (ComplexType*) st;
@@ -1949,11 +1977,15 @@ void ComplexType::resolveSimpleTypeExtension() {
             basefield->setTypeValue(old_type);
             basefield->getEnumeration().modified = false;
           }
+          if (!hasRestrOrExt) {
+            st->addToNameDepList(basefield);
+            basefield->nameDep = st;
+          }
         }
       }
     } else if(!isBuiltInType(basefield->getType().convertedValue)){
          printError(module->getSchemaname(), name.convertedValue,
-          "Reference for a non-defined type: " + basefield->getReference().repr());
+          "Reference for a non-defined simpleType or complexType type: " + basefield->getReference().repr());
        TTCN3ModuleInventory::getInstance().incrNumErrors();
        return;
     }
@@ -1963,10 +1995,10 @@ void ComplexType::resolveSimpleTypeExtension() {
 
 void ComplexType::resolveSimpleTypeRestriction() {
   if (mode == restrictionMode && cmode == CT_simpletype_mode && basefield != NULL && !basefield->outside_reference.empty()) {
-    SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(basefield, want_BOTH);
+    SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(basefield, want_BOTH, c_simpleOrComplexType);
     if (st == NULL) {
       printError(module->getSchemaname(), name.convertedValue,
-        "Reference for a non-defined type: " + basefield->getReference().repr());
+        "Reference for a non-defined simpleType or complexType type: " + basefield->getReference().repr());
       TTCN3ModuleInventory::getInstance().incrNumErrors();
       return;
     }
@@ -2028,10 +2060,10 @@ void ComplexType::resolveSimpleTypeRestriction() {
         }
     }
   } else if (mode == restrictionMode && cmode == CT_simpletype_mode && basefield != NULL) {
-    ComplexType * ct = (ComplexType*) TTCN3ModuleInventory::getInstance().lookup(basefield, want_CT);
+    ComplexType * ct = (ComplexType*) TTCN3ModuleInventory::getInstance().lookup(basefield, want_CT, c_simpleOrComplexType);
     if (ct == NULL && !isBuiltInType(basefield->getType().convertedValue)) {
       printError(module->getSchemaname(), name.convertedValue,
-        "Reference for a non-defined type: " + basefield->getReference().repr());
+        "Reference for a non-defined simpleType or complexType type: " + basefield->getReference().repr());
       TTCN3ModuleInventory::getInstance().incrNumErrors();
       return;
     }
@@ -2064,10 +2096,10 @@ void ComplexType::resolveSimpleTypeRestriction() {
 
 void ComplexType::resolveComplexTypeExtension() {
   if (mode == extensionMode && cmode == CT_complextype_mode && !outside_reference.empty()) {
-    ComplexType * ct = (ComplexType*) TTCN3ModuleInventory::getInstance().lookup(this, want_CT);
+    ComplexType * ct = (ComplexType*) TTCN3ModuleInventory::getInstance().lookup(this, want_CT, c_simpleOrComplexType);
     if (ct == NULL) {
       printError(module->getSchemaname(), name.convertedValue,
-        "Reference for a non-defined type: " + getReference().repr());
+        "Reference for a non-defined simpleType or complexType type: " + getReference().repr());
       TTCN3ModuleInventory::getInstance().incrNumErrors();
       return;
     }
@@ -2143,10 +2175,10 @@ void ComplexType::resolveComplexTypeExtension() {
 
 void ComplexType::resolveComplexTypeRestriction() {
   if (mode == restrictionMode && cmode == CT_complextype_mode && !outside_reference.empty()) {
-    ComplexType * ct = (ComplexType*) TTCN3ModuleInventory::getInstance().lookup(this, want_CT);
+    ComplexType * ct = (ComplexType*) TTCN3ModuleInventory::getInstance().lookup(this, want_CT, c_simpleOrComplexType);
     if (ct == NULL) {
       printError(module->getSchemaname(), name.convertedValue,
-        "Reference for a non-defined type: " + getReference().repr());
+        "Reference for a non-defined simpleType or complexType type: " + getReference().repr());
       TTCN3ModuleInventory::getInstance().incrNumErrors();
       return;
     }
@@ -2241,8 +2273,16 @@ bool ComplexType::hasComplexRestriction(ComplexType* ct) const {
   return false;
 }
 
-void ComplexType::resolveUnion(SimpleType *st) {
+void ComplexType::resolveUnion() {
   if (parent != NULL && parent->with_union && xsdtype == n_simpleType && !outside_reference.empty()) {
+    SimpleType * st = (SimpleType*) TTCN3ModuleInventory::getInstance().lookup(this, want_BOTH, c_simpleType);
+    if (st == NULL && basefield == NULL) {
+      printError(module->getSchemaname(), name.convertedValue,
+        "Reference for a non-defined type: " + getReference().repr());
+      TTCN3ModuleInventory::getInstance().incrNumErrors();
+      outside_reference.set_resolved(NULL);
+      return;
+    }
     if (st->getXsdtype() != n_NOTSET) {
       ComplexType * ct = (ComplexType*) st;
       outside_reference.set_resolved(ct);
@@ -2268,7 +2308,7 @@ void ComplexType::modifyAttributeParent() {
 void ComplexType::addSubstitution(SimpleType * st){
   ComplexType * element;
   if(st->getXsdtype() == n_NOTSET || !complexfields.empty()){
-    element = new ComplexType(*st, fromTagSubstitution);
+    element = new ComplexType(*st, fromElementSubstitution);
   }else {
     element = new ComplexType(*(ComplexType*)st);
     element->variant.clear();
@@ -2380,14 +2420,14 @@ Mstring ComplexType::findRoot(const BlockValue block_value, SimpleType* elem, co
         if(ct->basefield != NULL && ct->basefield->getType().convertedValue.getValueWithoutPrefix(':') == head_type){
           return head_type;
         }else if(ct->basefield != NULL){
-          st = (SimpleType*)TTCN3ModuleInventory::getInstance().lookup(ct->basefield, want_BOTH);
+          st = (SimpleType*)TTCN3ModuleInventory::getInstance().lookup(ct->basefield, want_BOTH, c_unknown);
         }
       }
       if(st == NULL){
         st = (SimpleType*)(elem->getReference().get_ref());
       }
     }else if(elem->getMode() == noMode && (block_value == restriction || block_value == extension)){
-      st = (SimpleType*)TTCN3ModuleInventory::getInstance().lookup(this, elem->getType().convertedValue, want_BOTH);
+      st = (SimpleType*)TTCN3ModuleInventory::getInstance().lookup(this, elem->getType().convertedValue, want_BOTH, c_unknown);
     }
     if(st != NULL && elem != st){
       return findRoot(block_value, st, head_type, false);
